@@ -18,7 +18,6 @@
 
 /* The interfaces in this file are subject to change at any time. */
 
-#ident "$Id: vtedraw.c,v 1.15 2003/06/16 21:15:10 nalin Exp $"
 
 #include "../config.h"
 
@@ -41,22 +40,20 @@ struct _vte_draw_impl
 #ifndef X_DISPLAY_MISSING
 #ifdef HAVE_XFT2
 	&_vte_draw_xft,
-#endif
-#endif
+#endif /* HAVE_XFT2 */
+#endif /* !X_DISPLAY_MISSING */
 	&_vte_draw_ft2,
-#if GTK_CHECK_VERSION(2,2,0)
 #ifndef X_DISPLAY_MISSING
 #ifdef HAVE_GL
 	&_vte_draw_gl,
-#endif
-#endif
-#endif
+#endif /* HAVE_GL */
+#endif /* !X_DISPLAY_MISSING */
 	&_vte_draw_pango,
 #ifndef X_DISPLAY_MISSING
 #ifdef HAVE_PANGOX
 	&_vte_draw_pango_x,
-#endif
-#endif
+#endif /* HAVE_PANGOX */
+#endif /* !X_DISPLAY_MISSING */
 };
 
 struct _vte_draw *
@@ -67,7 +64,7 @@ _vte_draw_new(GtkWidget *widget)
 	char *var;
 
 	/* Create the structure. */
-	draw = g_malloc0(sizeof(struct _vte_draw));
+	draw = g_slice_new0(struct _vte_draw);
 	g_object_ref(G_OBJECT(widget));
 	draw->widget = widget;
 	draw->started = FALSE;
@@ -114,7 +111,7 @@ _vte_draw_free(struct _vte_draw *draw)
 	}
 	draw->started = FALSE;
 
-	g_free(draw);
+	g_slice_free(struct _vte_draw, draw);
 }
 
 GdkVisual *
@@ -129,9 +126,7 @@ GdkColormap *
 _vte_draw_get_colormap(struct _vte_draw *draw, gboolean maybe_use_default)
 {
 	GdkColormap *colormap;
-#if GTK_CHECK_VERSION(2,2,0)
 	GdkScreen *screen;
-#endif
 	g_return_val_if_fail(draw->impl != NULL, NULL);
 	g_return_val_if_fail(draw->impl->get_colormap != NULL, NULL);
 	colormap = draw->impl->get_colormap(draw);
@@ -141,16 +136,12 @@ _vte_draw_get_colormap(struct _vte_draw *draw, gboolean maybe_use_default)
 	if (!maybe_use_default) {
 		return NULL;
 	}
-#if GTK_CHECK_VERSION(2,2,0)
 	if (gtk_widget_has_screen(draw->widget)) {
 		screen = gtk_widget_get_screen(draw->widget);
 	} else {
 		screen = gdk_display_get_default_screen(gtk_widget_get_display(draw->widget));
 	}
 	colormap = gdk_screen_get_default_colormap(screen);
-#else
-	colormap = gdk_colormap_get_system();
-#endif
 	return colormap;
 }
 
@@ -215,11 +206,12 @@ _vte_draw_clear(struct _vte_draw *draw, gint x, gint y, gint width, gint height)
 
 void
 _vte_draw_set_text_font(struct _vte_draw *draw,
-			const PangoFontDescription *fontdesc)
+			const PangoFontDescription *fontdesc,
+			VteTerminalAntiAlias anti_alias)
 {
 	g_return_if_fail(draw->impl != NULL);
 	g_return_if_fail(draw->impl->set_text_font != NULL);
-	draw->impl->set_text_font(draw, fontdesc);
+	draw->impl->set_text_font(draw, fontdesc, anti_alias);
 }
 
 int
